# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`sssd`](#sssd): Manage SSSD.
* [`sssd::config`](#sssdconfig)
* [`sssd::daemon`](#sssddaemon)
* [`sssd::dbus`](#sssddbus): Manage the SSSD InfoPipe responder
* [`sssd::dbus::config`](#sssddbusconfig)
* [`sssd::dbus::install`](#sssddbusinstall)
* [`sssd::install`](#sssdinstall)
* [`sssd::params`](#sssdparams)

### Defined types

* [`sssd::domain`](#sssddomain): Define an SSSD domain.
* [`sssd::service`](#sssdservice): Define an SSSD service.

### Resource types

* [`sssd_conf`](#sssd_conf): Manages settings in an SSSD sssd.conf file.  The resource name can be used as a shortcut for specifying the section and setting parameters by

### Data types

* [`SSSD::AD::Access::Filter`](#sssdadaccessfilter)
* [`SSSD::AD::GPO::Default::Right`](#sssdadgpodefaultright)
* [`SSSD::Certificate::Verification`](#sssdcertificateverification)
* [`SSSD::LDAP::Access::Order`](#sssdldapaccessorder)
* [`SSSD::Provider::Access`](#sssdprovideraccess)
* [`SSSD::Provider::Auth`](#sssdproviderauth)
* [`SSSD::Provider::AutoFS`](#sssdproviderautofs):  @since 2.0.0
* [`SSSD::Provider::Chpass`](#sssdproviderchpass)
* [`SSSD::Provider::HostID`](#sssdproviderhostid)
* [`SSSD::Provider::ID`](#sssdproviderid)
* [`SSSD::Provider::SELinux`](#sssdproviderselinux)
* [`SSSD::Provider::Subdomains`](#sssdprovidersubdomains)
* [`SSSD::Provider::Sudo`](#sssdprovidersudo)
* [`SSSD::Search::Base`](#sssdsearchbase)
* [`SSSD::Subdomain::Inherit`](#sssdsubdomaininherit)
* [`SSSD::Type`](#sssdtype)

## Classes

### <a name="sssd"></a>`sssd`

Manage SSSD.

* **Since** 1.0.0

* **See also**
  * puppet_classes::sssd::dbus
    * sssd::dbus
  * puppet_defined_types::sssd::domain
    * sssd::domain
  * puppet_defined_types::sssd::service
    * sssd::service

#### Examples

##### Declaring the class

```puppet
include sssd
sssd::service { 'nss': }
sssd::domain { 'example.com':
  id_provider => 'ldap',
  ...
}
```

#### Parameters

The following parameters are available in the `sssd` class:

* [`conf_dir`](#conf_dir)
* [`conf_file`](#conf_file)
* [`domains`](#domains)
* [`package_name`](#package_name)
* [`service_name`](#service_name)
* [`services`](#services)
* [`service_enable`](#service_enable)
* [`service_ensure`](#service_ensure)
* [`socket_services`](#socket_services)
* [`use_socket_activation`](#use_socket_activation)
* [`debug`](#debug)
* [`debug_level`](#debug_level)
* [`debug_timestamps`](#debug_timestamps)
* [`debug_microseconds`](#debug_microseconds)
* [`config_file_version`](#config_file_version)
* [`reconnection_retries`](#reconnection_retries)
* [`re_expression`](#re_expression)
* [`full_name_format`](#full_name_format)
* [`try_inotify`](#try_inotify)
* [`krb5_rcache_dir`](#krb5_rcache_dir)
* [`user`](#user)
* [`default_domain_suffix`](#default_domain_suffix)
* [`override_space`](#override_space)
* [`certificate_verification`](#certificate_verification)
* [`disable_netlink`](#disable_netlink)
* [`enable_files_domain`](#enable_files_domain)
* [`domain_resolution_order`](#domain_resolution_order)

##### <a name="conf_dir"></a>`conf_dir`

Data type: `Stdlib::Absolutepath`



Default value: `$sssd::params::conf_dir`

##### <a name="conf_file"></a>`conf_file`

Data type: `Stdlib::Absolutepath`



Default value: `$sssd::params::conf_file`

##### <a name="domains"></a>`domains`

Data type: `Hash[String, Hash[String, Any]]`



Default value: `{}`

##### <a name="package_name"></a>`package_name`

Data type: `Variant[String, Array[String, 1]]`



Default value: `$sssd::params::package_name`

##### <a name="service_name"></a>`service_name`

Data type: `String`



Default value: `$sssd::params::service_name`

##### <a name="services"></a>`services`

Data type: `Hash[String, Hash[String, Any]]`



Default value: `{}`

##### <a name="service_enable"></a>`service_enable`

Data type: `Boolean`



Default value: ``true``

##### <a name="service_ensure"></a>`service_ensure`

Data type: `Enum['running', 'stopped']`



Default value: `'running'`

##### <a name="socket_services"></a>`socket_services`

Data type: `Hash[SSSD::Type, Variant[String, Array[String, 1]]]`



Default value: `$sssd::params::socket_services`

##### <a name="use_socket_activation"></a>`use_socket_activation`

Data type: `Boolean`



Default value: `$sssd::params::use_socket_activation`

##### <a name="debug"></a>`debug`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="debug_level"></a>`debug_level`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="debug_timestamps"></a>`debug_timestamps`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="debug_microseconds"></a>`debug_microseconds`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="config_file_version"></a>`config_file_version`

Data type: `Integer[2]`



Default value: `2`

##### <a name="reconnection_retries"></a>`reconnection_retries`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="re_expression"></a>`re_expression`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="full_name_format"></a>`full_name_format`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="try_inotify"></a>`try_inotify`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="krb5_rcache_dir"></a>`krb5_rcache_dir`

Data type: `Optional[Variant[Stdlib::Absolutepath, Enum['__LIBKRB5_DEFAULTS__']]]`



Default value: ``undef``

##### <a name="user"></a>`user`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="default_domain_suffix"></a>`default_domain_suffix`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="override_space"></a>`override_space`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="certificate_verification"></a>`certificate_verification`

Data type: `Optional[Array[SSSD::Certificate::Verification, 1]]`



Default value: ``undef``

##### <a name="disable_netlink"></a>`disable_netlink`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="enable_files_domain"></a>`enable_files_domain`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="domain_resolution_order"></a>`domain_resolution_order`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

### <a name="sssdconfig"></a>`sssd::config`

The sssd::config class.

### <a name="sssddaemon"></a>`sssd::daemon`

The sssd::daemon class.

### <a name="sssddbus"></a>`sssd::dbus`

Manage the SSSD InfoPipe responder

* **Since** 1.0.0

* **See also**
  * puppet_classes::sssd
    * sssd
  * puppet_defined_types::sssd::service
    * sssd::service

#### Examples

##### Declaring the class

```puppet
include dbus
include sssd
include sssd::dbus
```

#### Parameters

The following parameters are available in the `sssd::dbus` class:

* [`package_name`](#package_name)
* [`use_socket_activation`](#use_socket_activation)
* [`debug`](#debug)
* [`debug_level`](#debug_level)
* [`debug_timestamps`](#debug_timestamps)
* [`debug_microseconds`](#debug_microseconds)
* [`timeout`](#timeout)
* [`reconnection_retries`](#reconnection_retries)
* [`fd_limit`](#fd_limit)
* [`client_idle_timeout`](#client_idle_timeout)
* [`offline_timeout`](#offline_timeout)
* [`responder_idle_timeout`](#responder_idle_timeout)
* [`cache_first`](#cache_first)
* [`allowed_uids`](#allowed_uids)
* [`user_attributes`](#user_attributes)
* [`wildcard_limit`](#wildcard_limit)

##### <a name="package_name"></a>`package_name`

Data type: `String`



Default value: `$sssd::params::dbus_package_name`

##### <a name="use_socket_activation"></a>`use_socket_activation`

Data type: `Boolean`



Default value: `$sssd::use_socket_activation`

##### <a name="debug"></a>`debug`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="debug_level"></a>`debug_level`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="debug_timestamps"></a>`debug_timestamps`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="debug_microseconds"></a>`debug_microseconds`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="timeout"></a>`timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="reconnection_retries"></a>`reconnection_retries`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="fd_limit"></a>`fd_limit`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="client_idle_timeout"></a>`client_idle_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="offline_timeout"></a>`offline_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="responder_idle_timeout"></a>`responder_idle_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="cache_first"></a>`cache_first`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="allowed_uids"></a>`allowed_uids`

Data type: `Optional[Array[Variant[Integer[0], String], 1]]`



Default value: ``undef``

##### <a name="user_attributes"></a>`user_attributes`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="wildcard_limit"></a>`wildcard_limit`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

### <a name="sssddbusconfig"></a>`sssd::dbus::config`

The sssd::dbus::config class.

### <a name="sssddbusinstall"></a>`sssd::dbus::install`

The sssd::dbus::install class.

### <a name="sssdinstall"></a>`sssd::install`

The sssd::install class.

### <a name="sssdparams"></a>`sssd::params`

The sssd::params class.

## Defined types

### <a name="sssddomain"></a>`sssd::domain`

Define an SSSD domain.

* **Since** 1.0.0

* **See also**
  * puppet_classes::sssd
    * ::sssd

#### Examples

##### Define an LDAP domain

```puppet
include sssd
sssd::domain { 'example.com':
  id_provider           => 'ldap',
  ldap_schema           => 'rfc2307',
  ldap_uri              => ['ldap://192.0.2.1'],
  ldap_search_base      => 'dc=example,dc=com',
  ldap_tls_reqcert      => 'never',
  ldap_id_use_start_tls => false,
  ldap_default_bind_dn  => 'cn=Manager,dc=example,dc=com',
  ldap_default_authtok  => 'secret',
}
```

#### Parameters

The following parameters are available in the `sssd::domain` defined type:

* [`id_provider`](#id_provider)
* [`domain`](#domain)
* [`debug`](#debug)
* [`debug_level`](#debug_level)
* [`debug_timestamps`](#debug_timestamps)
* [`debug_microseconds`](#debug_microseconds)
* [`timeout`](#timeout)
* [`domain_type`](#domain_type)
* [`max_id`](#max_id)
* [`min_id`](#min_id)
* [`enumerate`](#enumerate)
* [`subdomain_enumerate`](#subdomain_enumerate)
* [`entry_cache_timeout`](#entry_cache_timeout)
* [`entry_cache_user_timeout`](#entry_cache_user_timeout)
* [`entry_cache_group_timeout`](#entry_cache_group_timeout)
* [`entry_cache_netgroup_timeout`](#entry_cache_netgroup_timeout)
* [`entry_cache_service_timeout`](#entry_cache_service_timeout)
* [`entry_cache_sudo_timeout`](#entry_cache_sudo_timeout)
* [`entry_cache_autofs_timeout`](#entry_cache_autofs_timeout)
* [`entry_cache_ssh_host_timeout`](#entry_cache_ssh_host_timeout)
* [`refresh_expired_interval`](#refresh_expired_interval)
* [`cache_credentials`](#cache_credentials)
* [`cache_credentials_minimal_first_factor_length`](#cache_credentials_minimal_first_factor_length)
* [`account_cache_expiration`](#account_cache_expiration)
* [`pwd_expiration_warning`](#pwd_expiration_warning)
* [`use_fully_qualified_names`](#use_fully_qualified_names)
* [`ignore_group_members`](#ignore_group_members)
* [`auth_provider`](#auth_provider)
* [`access_provider`](#access_provider)
* [`chpass_provider`](#chpass_provider)
* [`sudo_provider`](#sudo_provider)
* [`selinux_provider`](#selinux_provider)
* [`subdomains_provider`](#subdomains_provider)
* [`autofs_provider`](#autofs_provider)
* [`hostid_provider`](#hostid_provider)
* [`re_expression`](#re_expression)
* [`full_name_format`](#full_name_format)
* [`lookup_family_order`](#lookup_family_order)
* [`dns_resolver_timeout`](#dns_resolver_timeout)
* [`dns_discovery_domain`](#dns_discovery_domain)
* [`override_gid`](#override_gid)
* [`case_sensitive`](#case_sensitive)
* [`subdomain_inherit`](#subdomain_inherit)
* [`subdomain_homedir`](#subdomain_homedir)
* [`realmd_tags`](#realmd_tags)
* [`cached_auth_timeout`](#cached_auth_timeout)
* [`dyndns_update`](#dyndns_update)
* [`dyndns_ttl`](#dyndns_ttl)
* [`dyndns_iface`](#dyndns_iface)
* [`dyndns_refresh_interval`](#dyndns_refresh_interval)
* [`dyndns_update_ptr`](#dyndns_update_ptr)
* [`dyndns_force_tcp`](#dyndns_force_tcp)
* [`dyndns_auth`](#dyndns_auth)
* [`dyndns_server`](#dyndns_server)
* [`override_homedir`](#override_homedir)
* [`homedir_substring`](#homedir_substring)
* [`wildcard_limit`](#wildcard_limit)
* [`simple_allow_users`](#simple_allow_users)
* [`simple_deny_users`](#simple_deny_users)
* [`simple_allow_groups`](#simple_allow_groups)
* [`simple_deny_groups`](#simple_deny_groups)
* [`proxy_pam_target`](#proxy_pam_target)
* [`proxy_lib_name`](#proxy_lib_name)
* [`proxy_fast_alias`](#proxy_fast_alias)
* [`proxy_max_children`](#proxy_max_children)
* [`default_shell`](#default_shell)
* [`base_directory`](#base_directory)
* [`create_homedir`](#create_homedir)
* [`remove_homedir`](#remove_homedir)
* [`homedir_umask`](#homedir_umask)
* [`skel_dir`](#skel_dir)
* [`mail_dir`](#mail_dir)
* [`userdel_cmd`](#userdel_cmd)
* [`ldap_uri`](#ldap_uri)
* [`ldap_backup_uri`](#ldap_backup_uri)
* [`ldap_chpass_uri`](#ldap_chpass_uri)
* [`ldap_chpass_backup_uri`](#ldap_chpass_backup_uri)
* [`ldap_search_base`](#ldap_search_base)
* [`ldap_schema`](#ldap_schema)
* [`ldap_default_bind_dn`](#ldap_default_bind_dn)
* [`ldap_default_authtok_type`](#ldap_default_authtok_type)
* [`ldap_default_authtok`](#ldap_default_authtok)
* [`ldap_user_object_class`](#ldap_user_object_class)
* [`ldap_user_name`](#ldap_user_name)
* [`ldap_user_uid_number`](#ldap_user_uid_number)
* [`ldap_user_gid_number`](#ldap_user_gid_number)
* [`ldap_user_gecos`](#ldap_user_gecos)
* [`ldap_user_home_directory`](#ldap_user_home_directory)
* [`ldap_user_shell`](#ldap_user_shell)
* [`ldap_user_uuid`](#ldap_user_uuid)
* [`ldap_user_objectsid`](#ldap_user_objectsid)
* [`ldap_user_modify_timestamp`](#ldap_user_modify_timestamp)
* [`ldap_user_shadow_last_change`](#ldap_user_shadow_last_change)
* [`ldap_user_shadow_min`](#ldap_user_shadow_min)
* [`ldap_user_shadow_max`](#ldap_user_shadow_max)
* [`ldap_user_shadow_warning`](#ldap_user_shadow_warning)
* [`ldap_user_shadow_inactive`](#ldap_user_shadow_inactive)
* [`ldap_user_shadow_expire`](#ldap_user_shadow_expire)
* [`ldap_user_krb_last_pwd_change`](#ldap_user_krb_last_pwd_change)
* [`ldap_user_krb_password_expiration`](#ldap_user_krb_password_expiration)
* [`ldap_user_ad_account_expires`](#ldap_user_ad_account_expires)
* [`ldap_user_ad_user_account_control`](#ldap_user_ad_user_account_control)
* [`ldap_ns_account_lock`](#ldap_ns_account_lock)
* [`ldap_user_nds_login_disabled`](#ldap_user_nds_login_disabled)
* [`ldap_user_nds_login_expiration_time`](#ldap_user_nds_login_expiration_time)
* [`ldap_user_nds_login_allowed_time_map`](#ldap_user_nds_login_allowed_time_map)
* [`ldap_user_principal`](#ldap_user_principal)
* [`ldap_user_extra_attrs`](#ldap_user_extra_attrs)
* [`ldap_user_ssh_public_key`](#ldap_user_ssh_public_key)
* [`ldap_force_upper_case_realm`](#ldap_force_upper_case_realm)
* [`ldap_enumeration_refresh_timeout`](#ldap_enumeration_refresh_timeout)
* [`ldap_purge_cache_timeout`](#ldap_purge_cache_timeout)
* [`ldap_user_fullname`](#ldap_user_fullname)
* [`ldap_user_member_of`](#ldap_user_member_of)
* [`ldap_user_authorized_service`](#ldap_user_authorized_service)
* [`ldap_user_authorized_host`](#ldap_user_authorized_host)
* [`ldap_user_certificate`](#ldap_user_certificate)
* [`ldap_group_object_class`](#ldap_group_object_class)
* [`ldap_group_name`](#ldap_group_name)
* [`ldap_group_gid_number`](#ldap_group_gid_number)
* [`ldap_group_member`](#ldap_group_member)
* [`ldap_group_uuid`](#ldap_group_uuid)
* [`ldap_group_objectsid`](#ldap_group_objectsid)
* [`ldap_group_modify_timestamp`](#ldap_group_modify_timestamp)
* [`ldap_group_type`](#ldap_group_type)
* [`ldap_group_external_member`](#ldap_group_external_member)
* [`ldap_group_nesting_level`](#ldap_group_nesting_level)
* [`ldap_groups_use_matching_rule_in_chain`](#ldap_groups_use_matching_rule_in_chain)
* [`ldap_initgroups_use_matching_rule_in_chain`](#ldap_initgroups_use_matching_rule_in_chain)
* [`ldap_use_tokengroups`](#ldap_use_tokengroups)
* [`ldap_netgroup_object_class`](#ldap_netgroup_object_class)
* [`ldap_netgroup_name`](#ldap_netgroup_name)
* [`ldap_netgroup_member`](#ldap_netgroup_member)
* [`ldap_netgroup_triple`](#ldap_netgroup_triple)
* [`ldap_netgroup_modify_timestamp`](#ldap_netgroup_modify_timestamp)
* [`ldap_service_object_class`](#ldap_service_object_class)
* [`ldap_service_name`](#ldap_service_name)
* [`ldap_service_port`](#ldap_service_port)
* [`ldap_service_proto`](#ldap_service_proto)
* [`ldap_service_search_base`](#ldap_service_search_base)
* [`ldap_search_timeout`](#ldap_search_timeout)
* [`ldap_enumeration_search_timeout`](#ldap_enumeration_search_timeout)
* [`ldap_network_timeout`](#ldap_network_timeout)
* [`ldap_opt_timeout`](#ldap_opt_timeout)
* [`ldap_connection_expire_timeout`](#ldap_connection_expire_timeout)
* [`ldap_page_size`](#ldap_page_size)
* [`ldap_disable_paging`](#ldap_disable_paging)
* [`ldap_disable_range_retrieval`](#ldap_disable_range_retrieval)
* [`ldap_sasl_minssf`](#ldap_sasl_minssf)
* [`ldap_sasl_maxssf`](#ldap_sasl_maxssf)
* [`ldap_deref_threshold`](#ldap_deref_threshold)
* [`ldap_tls_reqcert`](#ldap_tls_reqcert)
* [`ldap_tls_cacert`](#ldap_tls_cacert)
* [`ldap_tls_cacertdir`](#ldap_tls_cacertdir)
* [`ldap_tls_cert`](#ldap_tls_cert)
* [`ldap_tls_key`](#ldap_tls_key)
* [`ldap_tls_cipher_suite`](#ldap_tls_cipher_suite)
* [`ldap_auth_disable_tls_never_use_in_production`](#ldap_auth_disable_tls_never_use_in_production)
* [`ldap_id_use_start_tls`](#ldap_id_use_start_tls)
* [`ldap_id_mapping`](#ldap_id_mapping)
* [`ldap_idmap_range_min`](#ldap_idmap_range_min)
* [`ldap_idmap_range_max`](#ldap_idmap_range_max)
* [`ldap_idmap_range_size`](#ldap_idmap_range_size)
* [`ldap_idmap_default_domain_sid`](#ldap_idmap_default_domain_sid)
* [`ldap_idmap_default_domain`](#ldap_idmap_default_domain)
* [`ldap_idmap_autorid_compat`](#ldap_idmap_autorid_compat)
* [`ldap_idmap_helper_table_size`](#ldap_idmap_helper_table_size)
* [`ldap_max_id`](#ldap_max_id)
* [`ldap_min_id`](#ldap_min_id)
* [`ldap_sasl_mech`](#ldap_sasl_mech)
* [`ldap_sasl_authid`](#ldap_sasl_authid)
* [`ldap_sasl_realm`](#ldap_sasl_realm)
* [`ldap_sasl_canonicalize`](#ldap_sasl_canonicalize)
* [`ldap_krb5_keytab`](#ldap_krb5_keytab)
* [`ldap_krb5_init_creds`](#ldap_krb5_init_creds)
* [`ldap_krb5_ticket_lifetime`](#ldap_krb5_ticket_lifetime)
* [`ldap_pwd_policy`](#ldap_pwd_policy)
* [`ldap_referrals`](#ldap_referrals)
* [`ldap_dns_service_name`](#ldap_dns_service_name)
* [`ldap_chpass_dns_service_name`](#ldap_chpass_dns_service_name)
* [`ldap_chpass_update_last_change`](#ldap_chpass_update_last_change)
* [`ldap_access_filter`](#ldap_access_filter)
* [`ldap_account_expire_policy`](#ldap_account_expire_policy)
* [`ldap_access_order`](#ldap_access_order)
* [`ldap_pwdlockout_dn`](#ldap_pwdlockout_dn)
* [`ldap_deref`](#ldap_deref)
* [`ldap_rfc2307_fallback_to_local_users`](#ldap_rfc2307_fallback_to_local_users)
* [`ldap_sudorule_object_class`](#ldap_sudorule_object_class)
* [`ldap_sudorule_name`](#ldap_sudorule_name)
* [`ldap_sudorule_command`](#ldap_sudorule_command)
* [`ldap_sudorule_host`](#ldap_sudorule_host)
* [`ldap_sudorule_user`](#ldap_sudorule_user)
* [`ldap_sudorule_option`](#ldap_sudorule_option)
* [`ldap_sudorule_runasuser`](#ldap_sudorule_runasuser)
* [`ldap_sudorule_runasgroup`](#ldap_sudorule_runasgroup)
* [`ldap_sudorule_notbefore`](#ldap_sudorule_notbefore)
* [`ldap_sudorule_notafter`](#ldap_sudorule_notafter)
* [`ldap_sudorule_order`](#ldap_sudorule_order)
* [`ldap_sudo_full_refresh_interval`](#ldap_sudo_full_refresh_interval)
* [`ldap_sudo_smart_refresh_interval`](#ldap_sudo_smart_refresh_interval)
* [`ldap_sudo_use_host_filter`](#ldap_sudo_use_host_filter)
* [`ldap_sudo_hostnames`](#ldap_sudo_hostnames)
* [`ldap_sudo_ip`](#ldap_sudo_ip)
* [`ldap_sudo_include_netgroups`](#ldap_sudo_include_netgroups)
* [`ldap_sudo_include_regexp`](#ldap_sudo_include_regexp)
* [`ldap_autofs_map_master_name`](#ldap_autofs_map_master_name)
* [`ldap_autofs_map_object_class`](#ldap_autofs_map_object_class)
* [`ldap_autofs_map_name`](#ldap_autofs_map_name)
* [`ldap_autofs_entry_object_class`](#ldap_autofs_entry_object_class)
* [`ldap_autofs_entry_key`](#ldap_autofs_entry_key)
* [`ldap_autofs_entry_value`](#ldap_autofs_entry_value)
* [`ldap_netgroup_search_base`](#ldap_netgroup_search_base)
* [`ldap_user_search_base`](#ldap_user_search_base)
* [`ldap_group_search_base`](#ldap_group_search_base)
* [`ldap_sudo_search_base`](#ldap_sudo_search_base)
* [`ldap_autofs_search_base`](#ldap_autofs_search_base)
* [`krb5_server`](#krb5_server)
* [`krb5_backup_server`](#krb5_backup_server)
* [`krb5_realm`](#krb5_realm)
* [`krb5_kpasswd`](#krb5_kpasswd)
* [`krb5_backup_kpasswd`](#krb5_backup_kpasswd)
* [`krb5_ccachedir`](#krb5_ccachedir)
* [`krb5_ccname_template`](#krb5_ccname_template)
* [`krb5_auth_timeout`](#krb5_auth_timeout)
* [`krb5_validate`](#krb5_validate)
* [`krb5_keytab`](#krb5_keytab)
* [`krb5_store_password_if_offline`](#krb5_store_password_if_offline)
* [`krb5_renewable_lifetime`](#krb5_renewable_lifetime)
* [`krb5_lifetime`](#krb5_lifetime)
* [`krb5_renew_interval`](#krb5_renew_interval)
* [`krb5_use_fast`](#krb5_use_fast)
* [`krb5_fast_principal`](#krb5_fast_principal)
* [`krb5_canonicalize`](#krb5_canonicalize)
* [`krb5_use_kdcinfo`](#krb5_use_kdcinfo)
* [`krb5_use_enterprise_principal`](#krb5_use_enterprise_principal)
* [`krb5_map_user`](#krb5_map_user)
* [`krb5_confd_path`](#krb5_confd_path)
* [`ad_domain`](#ad_domain)
* [`ad_enabled_domains`](#ad_enabled_domains)
* [`ad_server`](#ad_server)
* [`ad_backup_server`](#ad_backup_server)
* [`ad_hostname`](#ad_hostname)
* [`ad_enable_dns_sites`](#ad_enable_dns_sites)
* [`ad_access_filter`](#ad_access_filter)
* [`ad_site`](#ad_site)
* [`ad_enable_gc`](#ad_enable_gc)
* [`ad_gpo_access_control`](#ad_gpo_access_control)
* [`ad_gpo_cache_timeout`](#ad_gpo_cache_timeout)
* [`ad_gpo_map_interactive`](#ad_gpo_map_interactive)
* [`ad_gpo_map_remote_interactive`](#ad_gpo_map_remote_interactive)
* [`ad_gpo_map_network`](#ad_gpo_map_network)
* [`ad_gpo_map_batch`](#ad_gpo_map_batch)
* [`ad_gpo_map_service`](#ad_gpo_map_service)
* [`ad_gpo_map_permit`](#ad_gpo_map_permit)
* [`ad_gpo_map_deny`](#ad_gpo_map_deny)
* [`ad_gpo_default_right`](#ad_gpo_default_right)
* [`ad_maximum_machine_account_password_age`](#ad_maximum_machine_account_password_age)
* [`ad_machine_account_password_renewal_opts`](#ad_machine_account_password_renewal_opts)
* [`ipa_domain`](#ipa_domain)
* [`ipa_server`](#ipa_server)
* [`ipa_backup_server`](#ipa_backup_server)
* [`ipa_hostname`](#ipa_hostname)
* [`ipa_enable_dns_sites`](#ipa_enable_dns_sites)
* [`ipa_hbac_search_base`](#ipa_hbac_search_base)
* [`ipa_host_search_base`](#ipa_host_search_base)
* [`ipa_selinux_search_base`](#ipa_selinux_search_base)
* [`ipa_subdomains_search_base`](#ipa_subdomains_search_base)
* [`ipa_master_domain_search_base`](#ipa_master_domain_search_base)
* [`ipa_views_search_base`](#ipa_views_search_base)
* [`ipa_hbac_refresh`](#ipa_hbac_refresh)
* [`ipa_hbac_selinux`](#ipa_hbac_selinux)
* [`ipa_server_mode`](#ipa_server_mode)
* [`ipa_automount_location`](#ipa_automount_location)
* [`ipa_view_class`](#ipa_view_class)
* [`ipa_view_name`](#ipa_view_name)
* [`ipa_override_object_class`](#ipa_override_object_class)
* [`ipa_anchor_uuid`](#ipa_anchor_uuid)
* [`ipa_user_override_object_class`](#ipa_user_override_object_class)
* [`ipa_group_override_object_class`](#ipa_group_override_object_class)

##### <a name="id_provider"></a>`id_provider`

Data type: `SSSD::Provider::ID`



##### <a name="domain"></a>`domain`

Data type: `String`



Default value: `$title`

##### <a name="debug"></a>`debug`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="debug_level"></a>`debug_level`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="debug_timestamps"></a>`debug_timestamps`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="debug_microseconds"></a>`debug_microseconds`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="timeout"></a>`timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="domain_type"></a>`domain_type`

Data type: `Optional[Enum['posix', 'application']]`



Default value: ``undef``

##### <a name="max_id"></a>`max_id`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="min_id"></a>`min_id`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="enumerate"></a>`enumerate`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="subdomain_enumerate"></a>`subdomain_enumerate`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="entry_cache_timeout"></a>`entry_cache_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="entry_cache_user_timeout"></a>`entry_cache_user_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="entry_cache_group_timeout"></a>`entry_cache_group_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="entry_cache_netgroup_timeout"></a>`entry_cache_netgroup_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="entry_cache_service_timeout"></a>`entry_cache_service_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="entry_cache_sudo_timeout"></a>`entry_cache_sudo_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="entry_cache_autofs_timeout"></a>`entry_cache_autofs_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="entry_cache_ssh_host_timeout"></a>`entry_cache_ssh_host_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="refresh_expired_interval"></a>`refresh_expired_interval`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="cache_credentials"></a>`cache_credentials`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="cache_credentials_minimal_first_factor_length"></a>`cache_credentials_minimal_first_factor_length`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="account_cache_expiration"></a>`account_cache_expiration`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="pwd_expiration_warning"></a>`pwd_expiration_warning`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="use_fully_qualified_names"></a>`use_fully_qualified_names`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ignore_group_members"></a>`ignore_group_members`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="auth_provider"></a>`auth_provider`

Data type: `Optional[SSSD::Provider::Auth]`



Default value: ``undef``

##### <a name="access_provider"></a>`access_provider`

Data type: `Optional[SSSD::Provider::Access]`



Default value: ``undef``

##### <a name="chpass_provider"></a>`chpass_provider`

Data type: `Optional[SSSD::Provider::Chpass]`



Default value: ``undef``

##### <a name="sudo_provider"></a>`sudo_provider`

Data type: `Optional[SSSD::Provider::Sudo]`



Default value: ``undef``

##### <a name="selinux_provider"></a>`selinux_provider`

Data type: `Optional[SSSD::Provider::SELinux]`



Default value: ``undef``

##### <a name="subdomains_provider"></a>`subdomains_provider`

Data type: `Optional[SSSD::Provider::Subdomains]`



Default value: ``undef``

##### <a name="autofs_provider"></a>`autofs_provider`

Data type: `Optional[SSSD::Provider::AutoFS]`



Default value: ``undef``

##### <a name="hostid_provider"></a>`hostid_provider`

Data type: `Optional[SSSD::Provider::HostID]`



Default value: ``undef``

##### <a name="re_expression"></a>`re_expression`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="full_name_format"></a>`full_name_format`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="lookup_family_order"></a>`lookup_family_order`

Data type: `Optional[Enum['ipv4_first', 'ipv4_only', 'ipv6_first', 'ipv6_only']]`



Default value: ``undef``

##### <a name="dns_resolver_timeout"></a>`dns_resolver_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="dns_discovery_domain"></a>`dns_discovery_domain`

Data type: `Optional[Bodgitlib::Domain]`



Default value: ``undef``

##### <a name="override_gid"></a>`override_gid`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="case_sensitive"></a>`case_sensitive`

Data type: `Optional[Variant[Boolean, Enum['preserving']]]`



Default value: ``undef``

##### <a name="subdomain_inherit"></a>`subdomain_inherit`

Data type: `Optional[Array[SSSD::Subdomain::Inherit, 1]]`



Default value: ``undef``

##### <a name="subdomain_homedir"></a>`subdomain_homedir`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="realmd_tags"></a>`realmd_tags`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="cached_auth_timeout"></a>`cached_auth_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="dyndns_update"></a>`dyndns_update`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="dyndns_ttl"></a>`dyndns_ttl`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="dyndns_iface"></a>`dyndns_iface`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="dyndns_refresh_interval"></a>`dyndns_refresh_interval`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="dyndns_update_ptr"></a>`dyndns_update_ptr`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="dyndns_force_tcp"></a>`dyndns_force_tcp`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="dyndns_auth"></a>`dyndns_auth`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="dyndns_server"></a>`dyndns_server`

Data type: `Optional[Bodgitlib::Host]`



Default value: ``undef``

##### <a name="override_homedir"></a>`override_homedir`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="homedir_substring"></a>`homedir_substring`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="wildcard_limit"></a>`wildcard_limit`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="simple_allow_users"></a>`simple_allow_users`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="simple_deny_users"></a>`simple_deny_users`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="simple_allow_groups"></a>`simple_allow_groups`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="simple_deny_groups"></a>`simple_deny_groups`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="proxy_pam_target"></a>`proxy_pam_target`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="proxy_lib_name"></a>`proxy_lib_name`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="proxy_fast_alias"></a>`proxy_fast_alias`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="proxy_max_children"></a>`proxy_max_children`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="default_shell"></a>`default_shell`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="base_directory"></a>`base_directory`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="create_homedir"></a>`create_homedir`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="remove_homedir"></a>`remove_homedir`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="homedir_umask"></a>`homedir_umask`

Data type: `Optional[Pattern[/^[0-7]{3}$/]]`



Default value: ``undef``

##### <a name="skel_dir"></a>`skel_dir`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="mail_dir"></a>`mail_dir`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="userdel_cmd"></a>`userdel_cmd`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="ldap_uri"></a>`ldap_uri`

Data type: `Optional[Array[Variant[Bodgitlib::LDAP::URI::Simple, Enum['_srv_']], 1]]`



Default value: ``undef``

##### <a name="ldap_backup_uri"></a>`ldap_backup_uri`

Data type: `Optional[Array[Bodgitlib::LDAP::URI::Simple, 1]]`



Default value: ``undef``

##### <a name="ldap_chpass_uri"></a>`ldap_chpass_uri`

Data type: `Optional[Array[Variant[Bodgitlib::LDAP::URI::Simple, Enum['_srv_']], 1]]`



Default value: ``undef``

##### <a name="ldap_chpass_backup_uri"></a>`ldap_chpass_backup_uri`

Data type: `Optional[Array[Bodgitlib::LDAP::URI::Simple, 1]]`



Default value: ``undef``

##### <a name="ldap_search_base"></a>`ldap_search_base`

Data type: `Optional[SSSD::Search::Base]`



Default value: ``undef``

##### <a name="ldap_schema"></a>`ldap_schema`

Data type: `Optional[Enum['rfc2307', 'rfc2307bis', 'ipa', 'ad']]`



Default value: ``undef``

##### <a name="ldap_default_bind_dn"></a>`ldap_default_bind_dn`

Data type: `Optional[Bodgitlib::LDAP::DN]`



Default value: ``undef``

##### <a name="ldap_default_authtok_type"></a>`ldap_default_authtok_type`

Data type: `Optional[Enum['password', 'obfuscated_password']]`



Default value: ``undef``

##### <a name="ldap_default_authtok"></a>`ldap_default_authtok`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_object_class"></a>`ldap_user_object_class`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_name"></a>`ldap_user_name`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_uid_number"></a>`ldap_user_uid_number`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_gid_number"></a>`ldap_user_gid_number`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_gecos"></a>`ldap_user_gecos`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_home_directory"></a>`ldap_user_home_directory`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_shell"></a>`ldap_user_shell`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_uuid"></a>`ldap_user_uuid`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_objectsid"></a>`ldap_user_objectsid`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_modify_timestamp"></a>`ldap_user_modify_timestamp`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_shadow_last_change"></a>`ldap_user_shadow_last_change`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_shadow_min"></a>`ldap_user_shadow_min`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_shadow_max"></a>`ldap_user_shadow_max`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_shadow_warning"></a>`ldap_user_shadow_warning`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_shadow_inactive"></a>`ldap_user_shadow_inactive`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_shadow_expire"></a>`ldap_user_shadow_expire`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_krb_last_pwd_change"></a>`ldap_user_krb_last_pwd_change`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_krb_password_expiration"></a>`ldap_user_krb_password_expiration`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_ad_account_expires"></a>`ldap_user_ad_account_expires`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_ad_user_account_control"></a>`ldap_user_ad_user_account_control`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_ns_account_lock"></a>`ldap_ns_account_lock`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_nds_login_disabled"></a>`ldap_user_nds_login_disabled`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_nds_login_expiration_time"></a>`ldap_user_nds_login_expiration_time`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_nds_login_allowed_time_map"></a>`ldap_user_nds_login_allowed_time_map`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_principal"></a>`ldap_user_principal`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_extra_attrs"></a>`ldap_user_extra_attrs`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="ldap_user_ssh_public_key"></a>`ldap_user_ssh_public_key`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_force_upper_case_realm"></a>`ldap_force_upper_case_realm`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_enumeration_refresh_timeout"></a>`ldap_enumeration_refresh_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_purge_cache_timeout"></a>`ldap_purge_cache_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_user_fullname"></a>`ldap_user_fullname`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_member_of"></a>`ldap_user_member_of`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_authorized_service"></a>`ldap_user_authorized_service`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_authorized_host"></a>`ldap_user_authorized_host`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_user_certificate"></a>`ldap_user_certificate`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_group_object_class"></a>`ldap_group_object_class`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_group_name"></a>`ldap_group_name`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_group_gid_number"></a>`ldap_group_gid_number`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_group_member"></a>`ldap_group_member`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_group_uuid"></a>`ldap_group_uuid`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_group_objectsid"></a>`ldap_group_objectsid`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_group_modify_timestamp"></a>`ldap_group_modify_timestamp`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_group_type"></a>`ldap_group_type`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_group_external_member"></a>`ldap_group_external_member`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_group_nesting_level"></a>`ldap_group_nesting_level`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_groups_use_matching_rule_in_chain"></a>`ldap_groups_use_matching_rule_in_chain`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_initgroups_use_matching_rule_in_chain"></a>`ldap_initgroups_use_matching_rule_in_chain`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_use_tokengroups"></a>`ldap_use_tokengroups`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_netgroup_object_class"></a>`ldap_netgroup_object_class`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_netgroup_name"></a>`ldap_netgroup_name`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_netgroup_member"></a>`ldap_netgroup_member`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_netgroup_triple"></a>`ldap_netgroup_triple`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_netgroup_modify_timestamp"></a>`ldap_netgroup_modify_timestamp`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_service_object_class"></a>`ldap_service_object_class`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_service_name"></a>`ldap_service_name`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_service_port"></a>`ldap_service_port`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_service_proto"></a>`ldap_service_proto`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_service_search_base"></a>`ldap_service_search_base`

Data type: `Optional[SSSD::Search::Base]`



Default value: ``undef``

##### <a name="ldap_search_timeout"></a>`ldap_search_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_enumeration_search_timeout"></a>`ldap_enumeration_search_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_network_timeout"></a>`ldap_network_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_opt_timeout"></a>`ldap_opt_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_connection_expire_timeout"></a>`ldap_connection_expire_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_page_size"></a>`ldap_page_size`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_disable_paging"></a>`ldap_disable_paging`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_disable_range_retrieval"></a>`ldap_disable_range_retrieval`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_sasl_minssf"></a>`ldap_sasl_minssf`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_sasl_maxssf"></a>`ldap_sasl_maxssf`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_deref_threshold"></a>`ldap_deref_threshold`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_tls_reqcert"></a>`ldap_tls_reqcert`

Data type: `Optional[Enum['never', 'allow', 'try', 'demand', 'hard']]`



Default value: ``undef``

##### <a name="ldap_tls_cacert"></a>`ldap_tls_cacert`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="ldap_tls_cacertdir"></a>`ldap_tls_cacertdir`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="ldap_tls_cert"></a>`ldap_tls_cert`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="ldap_tls_key"></a>`ldap_tls_key`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="ldap_tls_cipher_suite"></a>`ldap_tls_cipher_suite`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_auth_disable_tls_never_use_in_production"></a>`ldap_auth_disable_tls_never_use_in_production`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_id_use_start_tls"></a>`ldap_id_use_start_tls`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_id_mapping"></a>`ldap_id_mapping`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_idmap_range_min"></a>`ldap_idmap_range_min`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_idmap_range_max"></a>`ldap_idmap_range_max`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_idmap_range_size"></a>`ldap_idmap_range_size`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_idmap_default_domain_sid"></a>`ldap_idmap_default_domain_sid`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_idmap_default_domain"></a>`ldap_idmap_default_domain`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_idmap_autorid_compat"></a>`ldap_idmap_autorid_compat`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_idmap_helper_table_size"></a>`ldap_idmap_helper_table_size`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_max_id"></a>`ldap_max_id`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_min_id"></a>`ldap_min_id`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_sasl_mech"></a>`ldap_sasl_mech`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_sasl_authid"></a>`ldap_sasl_authid`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_sasl_realm"></a>`ldap_sasl_realm`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_sasl_canonicalize"></a>`ldap_sasl_canonicalize`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_krb5_keytab"></a>`ldap_krb5_keytab`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="ldap_krb5_init_creds"></a>`ldap_krb5_init_creds`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_krb5_ticket_lifetime"></a>`ldap_krb5_ticket_lifetime`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_pwd_policy"></a>`ldap_pwd_policy`

Data type: `Optional[Enum['none', 'shadow', 'mit_kerberos']]`



Default value: ``undef``

##### <a name="ldap_referrals"></a>`ldap_referrals`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_dns_service_name"></a>`ldap_dns_service_name`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_chpass_dns_service_name"></a>`ldap_chpass_dns_service_name`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_chpass_update_last_change"></a>`ldap_chpass_update_last_change`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_access_filter"></a>`ldap_access_filter`

Data type: `Optional[Bodgitlib::LDAP::Filter]`



Default value: ``undef``

##### <a name="ldap_account_expire_policy"></a>`ldap_account_expire_policy`

Data type: `Optional[Enum['shadow', 'ad', 'rhds', 'ipa', '389ds', 'nds']]`



Default value: ``undef``

##### <a name="ldap_access_order"></a>`ldap_access_order`

Data type: `Optional[Array[SSSD::LDAP::Access::Order, 1]]`



Default value: ``undef``

##### <a name="ldap_pwdlockout_dn"></a>`ldap_pwdlockout_dn`

Data type: `Optional[Bodgitlib::LDAP::DN]`



Default value: ``undef``

##### <a name="ldap_deref"></a>`ldap_deref`

Data type: `Optional[Enum['never', 'searching', 'finding', 'always']]`



Default value: ``undef``

##### <a name="ldap_rfc2307_fallback_to_local_users"></a>`ldap_rfc2307_fallback_to_local_users`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_sudorule_object_class"></a>`ldap_sudorule_object_class`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_sudorule_name"></a>`ldap_sudorule_name`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_sudorule_command"></a>`ldap_sudorule_command`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_sudorule_host"></a>`ldap_sudorule_host`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_sudorule_user"></a>`ldap_sudorule_user`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_sudorule_option"></a>`ldap_sudorule_option`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_sudorule_runasuser"></a>`ldap_sudorule_runasuser`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_sudorule_runasgroup"></a>`ldap_sudorule_runasgroup`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_sudorule_notbefore"></a>`ldap_sudorule_notbefore`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_sudorule_notafter"></a>`ldap_sudorule_notafter`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_sudorule_order"></a>`ldap_sudorule_order`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_sudo_full_refresh_interval"></a>`ldap_sudo_full_refresh_interval`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_sudo_smart_refresh_interval"></a>`ldap_sudo_smart_refresh_interval`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ldap_sudo_use_host_filter"></a>`ldap_sudo_use_host_filter`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_sudo_hostnames"></a>`ldap_sudo_hostnames`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="ldap_sudo_ip"></a>`ldap_sudo_ip`

Data type: `Optional[Array[IP::Address, 1]]`



Default value: ``undef``

##### <a name="ldap_sudo_include_netgroups"></a>`ldap_sudo_include_netgroups`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_sudo_include_regexp"></a>`ldap_sudo_include_regexp`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ldap_autofs_map_master_name"></a>`ldap_autofs_map_master_name`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_autofs_map_object_class"></a>`ldap_autofs_map_object_class`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_autofs_map_name"></a>`ldap_autofs_map_name`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_autofs_entry_object_class"></a>`ldap_autofs_entry_object_class`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_autofs_entry_key"></a>`ldap_autofs_entry_key`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_autofs_entry_value"></a>`ldap_autofs_entry_value`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ldap_netgroup_search_base"></a>`ldap_netgroup_search_base`

Data type: `Optional[SSSD::Search::Base]`



Default value: ``undef``

##### <a name="ldap_user_search_base"></a>`ldap_user_search_base`

Data type: `Optional[SSSD::Search::Base]`



Default value: ``undef``

##### <a name="ldap_group_search_base"></a>`ldap_group_search_base`

Data type: `Optional[SSSD::Search::Base]`



Default value: ``undef``

##### <a name="ldap_sudo_search_base"></a>`ldap_sudo_search_base`

Data type: `Optional[SSSD::Search::Base]`



Default value: ``undef``

##### <a name="ldap_autofs_search_base"></a>`ldap_autofs_search_base`

Data type: `Optional[SSSD::Search::Base]`



Default value: ``undef``

##### <a name="krb5_server"></a>`krb5_server`

Data type: `Optional[Array[Variant[Bodgitlib::Host, Enum['_srv_']], 1]]`



Default value: ``undef``

##### <a name="krb5_backup_server"></a>`krb5_backup_server`

Data type: `Optional[Array[Bodgitlib::Host, 1]]`



Default value: ``undef``

##### <a name="krb5_realm"></a>`krb5_realm`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="krb5_kpasswd"></a>`krb5_kpasswd`

Data type: `Optional[Array[Variant[Bodgitlib::Host, Tuple[Bodgitlib::Host, Bodgitlib::Port]], 1]]`



Default value: ``undef``

##### <a name="krb5_backup_kpasswd"></a>`krb5_backup_kpasswd`

Data type: `Optional[Array[Variant[Bodgitlib::Host, Tuple[Bodgitlib::Host, Bodgitlib::Port]], 1]]`



Default value: ``undef``

##### <a name="krb5_ccachedir"></a>`krb5_ccachedir`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="krb5_ccname_template"></a>`krb5_ccname_template`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="krb5_auth_timeout"></a>`krb5_auth_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="krb5_validate"></a>`krb5_validate`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="krb5_keytab"></a>`krb5_keytab`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="krb5_store_password_if_offline"></a>`krb5_store_password_if_offline`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="krb5_renewable_lifetime"></a>`krb5_renewable_lifetime`

Data type: `Optional[Variant[Integer[0], Pattern[/(?x) ^ \d+ [smhd]? $/]]]`



Default value: ``undef``

##### <a name="krb5_lifetime"></a>`krb5_lifetime`

Data type: `Optional[Variant[Integer[0], Pattern[/(?x) ^ \d+ [smhd]? $/]]]`



Default value: ``undef``

##### <a name="krb5_renew_interval"></a>`krb5_renew_interval`

Data type: `Optional[Variant[Integer[0], Pattern[/(?x) ^ \d+ [smhd]? $/]]]`



Default value: ``undef``

##### <a name="krb5_use_fast"></a>`krb5_use_fast`

Data type: `Optional[Enum['never', 'try', 'demand']]`



Default value: ``undef``

##### <a name="krb5_fast_principal"></a>`krb5_fast_principal`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="krb5_canonicalize"></a>`krb5_canonicalize`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="krb5_use_kdcinfo"></a>`krb5_use_kdcinfo`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="krb5_use_enterprise_principal"></a>`krb5_use_enterprise_principal`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="krb5_map_user"></a>`krb5_map_user`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="krb5_confd_path"></a>`krb5_confd_path`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="ad_domain"></a>`ad_domain`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ad_enabled_domains"></a>`ad_enabled_domains`

Data type: `Optional[Array[Bodgitlib::Domain, 1]]`



Default value: ``undef``

##### <a name="ad_server"></a>`ad_server`

Data type: `Optional[Array[Variant[Bodgitlib::Host, Enum['_srv_']], 1]]`



Default value: ``undef``

##### <a name="ad_backup_server"></a>`ad_backup_server`

Data type: `Optional[Array[Bodgitlib::Host, 1]]`



Default value: ``undef``

##### <a name="ad_hostname"></a>`ad_hostname`

Data type: `Optional[Bodgitlib::Hostname]`



Default value: ``undef``

##### <a name="ad_enable_dns_sites"></a>`ad_enable_dns_sites`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ad_access_filter"></a>`ad_access_filter`

Data type: `Optional[SSSD::AD::Access::Filter]`



Default value: ``undef``

##### <a name="ad_site"></a>`ad_site`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ad_enable_gc"></a>`ad_enable_gc`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ad_gpo_access_control"></a>`ad_gpo_access_control`

Data type: `Optional[Enum['disabled', 'enforcing', 'permissive']]`



Default value: ``undef``

##### <a name="ad_gpo_cache_timeout"></a>`ad_gpo_cache_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ad_gpo_map_interactive"></a>`ad_gpo_map_interactive`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="ad_gpo_map_remote_interactive"></a>`ad_gpo_map_remote_interactive`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="ad_gpo_map_network"></a>`ad_gpo_map_network`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="ad_gpo_map_batch"></a>`ad_gpo_map_batch`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="ad_gpo_map_service"></a>`ad_gpo_map_service`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="ad_gpo_map_permit"></a>`ad_gpo_map_permit`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="ad_gpo_map_deny"></a>`ad_gpo_map_deny`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="ad_gpo_default_right"></a>`ad_gpo_default_right`

Data type: `Optional[SSSD::AD::GPO::Default::Right]`



Default value: ``undef``

##### <a name="ad_maximum_machine_account_password_age"></a>`ad_maximum_machine_account_password_age`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ad_machine_account_password_renewal_opts"></a>`ad_machine_account_password_renewal_opts`

Data type: `Optional[Tuple[Integer[0], 2, 2]]`



Default value: ``undef``

##### <a name="ipa_domain"></a>`ipa_domain`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ipa_server"></a>`ipa_server`

Data type: `Optional[Array[Variant[Bodgitlib::Host, Enum['_srv_']], 1]]`



Default value: ``undef``

##### <a name="ipa_backup_server"></a>`ipa_backup_server`

Data type: `Optional[Array[Bodgitlib::Host, 1]]`



Default value: ``undef``

##### <a name="ipa_hostname"></a>`ipa_hostname`

Data type: `Optional[Bodgitlib::Hostname]`



Default value: ``undef``

##### <a name="ipa_enable_dns_sites"></a>`ipa_enable_dns_sites`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ipa_hbac_search_base"></a>`ipa_hbac_search_base`

Data type: `Optional[Bodgitlib::LDAP::DN]`



Default value: ``undef``

##### <a name="ipa_host_search_base"></a>`ipa_host_search_base`

Data type: `Optional[Bodgitlib::LDAP::DN]`



Default value: ``undef``

##### <a name="ipa_selinux_search_base"></a>`ipa_selinux_search_base`

Data type: `Optional[Bodgitlib::LDAP::DN]`



Default value: ``undef``

##### <a name="ipa_subdomains_search_base"></a>`ipa_subdomains_search_base`

Data type: `Optional[Bodgitlib::LDAP::DN]`



Default value: ``undef``

##### <a name="ipa_master_domain_search_base"></a>`ipa_master_domain_search_base`

Data type: `Optional[Bodgitlib::LDAP::DN]`



Default value: ``undef``

##### <a name="ipa_views_search_base"></a>`ipa_views_search_base`

Data type: `Optional[Bodgitlib::LDAP::DN]`



Default value: ``undef``

##### <a name="ipa_hbac_refresh"></a>`ipa_hbac_refresh`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ipa_hbac_selinux"></a>`ipa_hbac_selinux`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ipa_server_mode"></a>`ipa_server_mode`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ipa_automount_location"></a>`ipa_automount_location`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ipa_view_class"></a>`ipa_view_class`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ipa_view_name"></a>`ipa_view_name`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ipa_override_object_class"></a>`ipa_override_object_class`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ipa_anchor_uuid"></a>`ipa_anchor_uuid`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ipa_user_override_object_class"></a>`ipa_user_override_object_class`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="ipa_group_override_object_class"></a>`ipa_group_override_object_class`

Data type: `Optional[String]`



Default value: ``undef``

### <a name="sssdservice"></a>`sssd::service`

Define an SSSD service.

* **Since** 1.0.0

* **See also**
  * puppet_classes::sssd
    * ::sssd
  * puppet_classes::sssd::dbus
    * ::sssd::dbus

#### Examples

##### Enable NSS service

```puppet
include sssd
sssd::service { 'nss': }
```

#### Parameters

The following parameters are available in the `sssd::service` defined type:

* [`service`](#service)
* [`use_socket_activation`](#use_socket_activation)
* [`debug`](#debug)
* [`debug_level`](#debug_level)
* [`debug_timestamps`](#debug_timestamps)
* [`debug_microseconds`](#debug_microseconds)
* [`timeout`](#timeout)
* [`reconnection_retries`](#reconnection_retries)
* [`fd_limit`](#fd_limit)
* [`client_idle_timeout`](#client_idle_timeout)
* [`offline_timeout`](#offline_timeout)
* [`responder_idle_timeout`](#responder_idle_timeout)
* [`cache_first`](#cache_first)
* [`enum_cache_timeout`](#enum_cache_timeout)
* [`entry_cache_nowait_percentage`](#entry_cache_nowait_percentage)
* [`entry_negative_timeout`](#entry_negative_timeout)
* [`local_negative_timeout`](#local_negative_timeout)
* [`filter_groups`](#filter_groups)
* [`filter_users`](#filter_users)
* [`filter_users_in_groups`](#filter_users_in_groups)
* [`override_homedir`](#override_homedir)
* [`homedir_substring`](#homedir_substring)
* [`fallback_homedir`](#fallback_homedir)
* [`override_shell`](#override_shell)
* [`allowed_shells`](#allowed_shells)
* [`vetoed_shells`](#vetoed_shells)
* [`shell_fallback`](#shell_fallback)
* [`default_shell`](#default_shell)
* [`get_domains_timeout`](#get_domains_timeout)
* [`memcache_timeout`](#memcache_timeout)
* [`user_attributes`](#user_attributes)
* [`pwfield`](#pwfield)
* [`offline_credentials_expiration`](#offline_credentials_expiration)
* [`offline_failed_login_attempts`](#offline_failed_login_attempts)
* [`offline_failed_login_delay`](#offline_failed_login_delay)
* [`pam_verbosity`](#pam_verbosity)
* [`pam_response_filter`](#pam_response_filter)
* [`pam_id_timeout`](#pam_id_timeout)
* [`pam_pwd_expiration_warning`](#pam_pwd_expiration_warning)
* [`pam_trusted_users`](#pam_trusted_users)
* [`pam_public_domains`](#pam_public_domains)
* [`pam_account_expired_message`](#pam_account_expired_message)
* [`pam_account_locked_message`](#pam_account_locked_message)
* [`pam_cert_auth`](#pam_cert_auth)
* [`pam_cert_db_path`](#pam_cert_db_path)
* [`p11_child_timeout`](#p11_child_timeout)
* [`pam_app_services`](#pam_app_services)
* [`sudo_timed`](#sudo_timed)
* [`autofs_negative_timeout`](#autofs_negative_timeout)
* [`ssh_hash_known_hosts`](#ssh_hash_known_hosts)
* [`ssh_known_hosts_timeout`](#ssh_known_hosts_timeout)
* [`ca_db`](#ca_db)
* [`allowed_uids`](#allowed_uids)
* [`pac_lifetime`](#pac_lifetime)
* [`wildcard_limit`](#wildcard_limit)
* [`provider`](#provider)
* [`container_nest_level`](#container_nest_level)
* [`max_secrets`](#max_secrets)
* [`max_payload_size`](#max_payload_size)
* [`proxy_url`](#proxy_url)
* [`auth_type`](#auth_type)
* [`auth_header_name`](#auth_header_name)
* [`auth_header_value`](#auth_header_value)
* [`forward_headers`](#forward_headers)
* [`verify_peer`](#verify_peer)
* [`verify_host`](#verify_host)
* [`capath`](#capath)
* [`cacert`](#cacert)
* [`cert`](#cert)
* [`key`](#key)

##### <a name="service"></a>`service`

Data type: `SSSD::Type`



Default value: `$title`

##### <a name="use_socket_activation"></a>`use_socket_activation`

Data type: `Boolean`



Default value: `$sssd::use_socket_activation`

##### <a name="debug"></a>`debug`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="debug_level"></a>`debug_level`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="debug_timestamps"></a>`debug_timestamps`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="debug_microseconds"></a>`debug_microseconds`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="timeout"></a>`timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="reconnection_retries"></a>`reconnection_retries`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="fd_limit"></a>`fd_limit`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="client_idle_timeout"></a>`client_idle_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="offline_timeout"></a>`offline_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="responder_idle_timeout"></a>`responder_idle_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="cache_first"></a>`cache_first`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="enum_cache_timeout"></a>`enum_cache_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="entry_cache_nowait_percentage"></a>`entry_cache_nowait_percentage`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="entry_negative_timeout"></a>`entry_negative_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="local_negative_timeout"></a>`local_negative_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="filter_groups"></a>`filter_groups`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="filter_users"></a>`filter_users`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="filter_users_in_groups"></a>`filter_users_in_groups`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="override_homedir"></a>`override_homedir`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="homedir_substring"></a>`homedir_substring`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="fallback_homedir"></a>`fallback_homedir`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="override_shell"></a>`override_shell`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="allowed_shells"></a>`allowed_shells`

Data type: `Optional[Array[Variant[Stdlib::Absolutepath, Enum['*']], 1]]`



Default value: ``undef``

##### <a name="vetoed_shells"></a>`vetoed_shells`

Data type: `Optional[Array[Stdlib::Absolutepath, 1]]`



Default value: ``undef``

##### <a name="shell_fallback"></a>`shell_fallback`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="default_shell"></a>`default_shell`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="get_domains_timeout"></a>`get_domains_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="memcache_timeout"></a>`memcache_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="user_attributes"></a>`user_attributes`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="pwfield"></a>`pwfield`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="offline_credentials_expiration"></a>`offline_credentials_expiration`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="offline_failed_login_attempts"></a>`offline_failed_login_attempts`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="offline_failed_login_delay"></a>`offline_failed_login_delay`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="pam_verbosity"></a>`pam_verbosity`

Data type: `Optional[Integer[0, 3]]`



Default value: ``undef``

##### <a name="pam_response_filter"></a>`pam_response_filter`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="pam_id_timeout"></a>`pam_id_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="pam_pwd_expiration_warning"></a>`pam_pwd_expiration_warning`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="pam_trusted_users"></a>`pam_trusted_users`

Data type: `Optional[Array[Variant[Integer[0], String], 1]]`



Default value: ``undef``

##### <a name="pam_public_domains"></a>`pam_public_domains`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="pam_account_expired_message"></a>`pam_account_expired_message`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="pam_account_locked_message"></a>`pam_account_locked_message`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="pam_cert_auth"></a>`pam_cert_auth`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="pam_cert_db_path"></a>`pam_cert_db_path`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="p11_child_timeout"></a>`p11_child_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="pam_app_services"></a>`pam_app_services`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="sudo_timed"></a>`sudo_timed`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="autofs_negative_timeout"></a>`autofs_negative_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ssh_hash_known_hosts"></a>`ssh_hash_known_hosts`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="ssh_known_hosts_timeout"></a>`ssh_known_hosts_timeout`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="ca_db"></a>`ca_db`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="allowed_uids"></a>`allowed_uids`

Data type: `Optional[Array[Variant[Integer[0], String], 1]]`



Default value: ``undef``

##### <a name="pac_lifetime"></a>`pac_lifetime`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="wildcard_limit"></a>`wildcard_limit`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="provider"></a>`provider`

Data type: `Optional[Enum['local', 'proxy']]`



Default value: ``undef``

##### <a name="container_nest_level"></a>`container_nest_level`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="max_secrets"></a>`max_secrets`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="max_payload_size"></a>`max_payload_size`

Data type: `Optional[Integer[0]]`



Default value: ``undef``

##### <a name="proxy_url"></a>`proxy_url`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="auth_type"></a>`auth_type`

Data type: `Optional[Enum['basic_auth', 'header']]`



Default value: ``undef``

##### <a name="auth_header_name"></a>`auth_header_name`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="auth_header_value"></a>`auth_header_value`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="forward_headers"></a>`forward_headers`

Data type: `Optional[Array[String, 1]]`



Default value: ``undef``

##### <a name="verify_peer"></a>`verify_peer`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="verify_host"></a>`verify_host`

Data type: `Optional[Boolean]`



Default value: ``undef``

##### <a name="capath"></a>`capath`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="cacert"></a>`cacert`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="cert"></a>`cert`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

##### <a name="key"></a>`key`

Data type: `Optional[Stdlib::Absolutepath]`



Default value: ``undef``

## Resource types

### <a name="sssd_conf"></a>`sssd_conf`

Manages settings in an SSSD sssd.conf file.

The resource name can be used as a shortcut for specifying the section and
setting parameters by using the form `<section>/<setting>` otherwise it can be
left as a normal string.

#### Properties

The following properties are available in the `sssd_conf` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `value`

Value to change the setting to.

#### Parameters

The following parameters are available in the `sssd_conf` type.

* [`name`](#name)
* [`provider`](#provider)
* [`section`](#section)
* [`setting`](#setting)
* [`target`](#target)

##### <a name="name"></a>`name`

The name of the section and setting separated by `/`, or a unique
string.

##### <a name="provider"></a>`provider`

The specific backend to use for this `sssd_conf` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### <a name="section"></a>`section`

namevar

The section in the sssd.conf file for the setting, defaults to the
global [sssd] section.

Default value: `sssd`

##### <a name="setting"></a>`setting`

namevar

The setting in the sssd.conf file to manage.

##### <a name="target"></a>`target`

The file in which to store the settings, defaults to
`/etc/sssd/sssd.conf`.

## Data types

### <a name="sssdadaccessfilter"></a>`SSSD::AD::Access::Filter`

The SSSD::AD::Access::Filter data type.

* **Since** 2.0.0

Alias of

```puppet
Pattern[/(?x) ^ (?: (?: (?: DOM | FOREST ) : )? [^:]+ : )? (?<re> \( (?: [&|] \g<re>+ | ! \g<re> | (?: (?<attr> (?: [[:alpha:]] [[:alnum:]_-]* | [[:digit:]]+ (?: \. [[:digit:]]+ )* ) (?: ; [[:alpha:]] [[:alnum:]-]* )* ) [~<>]? = (?<value> (?: [^\\()*] | \\ [[:xdigit:]]{2} )* ) | \g<attr> = \* | \g<attr> = \g<value>? \* (?: \g<value> \* )* \g<value>? | (?: \g<attr> (?: :dn )? (?: : (?<rule> [[:digit:]]+ (?: \. [[:digit:]]+ )* | [[:alpha:]] [[:alnum:]]* Match ) )? := \g<value> | (?: : (?: dn | DN ) )? : \g<rule> := \g<value> ) ) ) \) ) $/]
```

### <a name="sssdadgpodefaultright"></a>`SSSD::AD::GPO::Default::Right`

The SSSD::AD::GPO::Default::Right data type.

* **Since** 2.0.0

Alias of

```puppet
Enum['interactive', 'remote_interactive', 'network', 'batch', 'service', 'permit', 'deny']
```

### <a name="sssdcertificateverification"></a>`SSSD::Certificate::Verification`

The SSSD::Certificate::Verification data type.

* **Since** 2.0.0

Alias of

```puppet
Variant[Enum['no_ocsp', 'no_verification'], Tuple[Enum['ocsp_default_responder', 'ocsp_default_responder_signing_cert'], String]]
```

### <a name="sssdldapaccessorder"></a>`SSSD::LDAP::Access::Order`

The SSSD::LDAP::Access::Order data type.

* **Since** 2.0.0

Alias of

```puppet
Enum['filter', 'lockout', 'ppolicy', 'expire', 'pwd_expire_policy_reject', 'pwd_expire_policy_warn', 'pwd_expire_policy_renew', 'authorized_service', 'host']
```

### <a name="sssdprovideraccess"></a>`SSSD::Provider::Access`

The SSSD::Provider::Access data type.

* **Since** 2.0.0

Alias of

```puppet
Enum['permit', 'deny', 'ldap', 'ipa', 'ad', 'simple', 'krb5', 'proxy']
```

### <a name="sssdproviderauth"></a>`SSSD::Provider::Auth`

The SSSD::Provider::Auth data type.

* **Since** 2.0.0

Alias of

```puppet
Enum['ldap', 'krb5', 'ipa', 'ad', 'proxy', 'local', 'none']
```

### <a name="sssdproviderautofs"></a>`SSSD::Provider::AutoFS`

 @since 2.0.0

Alias of

```puppet
Enum['ldap', 'ipa', 'ad', 'none']
```

### <a name="sssdproviderchpass"></a>`SSSD::Provider::Chpass`

The SSSD::Provider::Chpass data type.

* **Since** 2.0.0

Alias of

```puppet
Enum['ldap', 'krb5', 'ipa', 'ad', 'proxy', 'none']
```

### <a name="sssdproviderhostid"></a>`SSSD::Provider::HostID`

The SSSD::Provider::HostID data type.

* **Since** 2.0.0

Alias of

```puppet
SSSD::Provider::SELinux
```

### <a name="sssdproviderid"></a>`SSSD::Provider::ID`

The SSSD::Provider::ID data type.

* **Since** 2.0.0

Alias of

```puppet
Enum['proxy', 'local', 'ldap', 'ipa', 'ad']
```

### <a name="sssdproviderselinux"></a>`SSSD::Provider::SELinux`

The SSSD::Provider::SELinux data type.

* **Since** 2.0.0

Alias of

```puppet
Enum['ipa', 'none']
```

### <a name="sssdprovidersubdomains"></a>`SSSD::Provider::Subdomains`

The SSSD::Provider::Subdomains data type.

* **Since** 2.0.0

Alias of

```puppet
Enum['ipa', 'ad', 'none']
```

### <a name="sssdprovidersudo"></a>`SSSD::Provider::Sudo`

The SSSD::Provider::Sudo data type.

* **Since** 2.0.0

Alias of

```puppet
Enum['ldap', 'ipa', 'ad', 'none']
```

### <a name="sssdsearchbase"></a>`SSSD::Search::Base`

The SSSD::Search::Base data type.

* **Since** 2.0.0

Alias of

```puppet
Pattern[/(?x) ^ (?<dn> (?<comp> (?<tv> (?: [[:alpha:]] [[:alnum:]_-]* | (?: (?: oid | OID ) \. )? [[:digit:]]+ (?: \. [[:digit:]]+ )* ) [[:space:]]* = [[:space:]]* (?: \# (?: [[:xdigit:]]{2} )+ | (?: [^,=\+<>#;\\"] | \\ [,=\+<>#;\\"] | \\ [[:xdigit:]]{2} )* | " (?: [^\\"] | \\ [,=\+<>#;\\"] | \\ [[:xdigit:]]{2} )* " ) ) (?: [[:space:]]* \+ [[:space:]]* \g<tv> )* ) (?: [[:space:]]* [,;] [[:space:]]* \g<comp> )* ) (?: \? (?<scope> base | onelevel | subtree ) \? (?<filter> \( (?: [&|] \g<filter>+ | ! \g<filter> | (?: (?<attr> (?: [[:alpha:]] [[:alnum:]_-]* | [[:digit:]]+ (?: \. [[:digit:]]+ )* ) (?: ; [[:alpha:]] [[:alnum:]-]* )* ) [~<>]? = (?<value> (?: [^\\()*] | \\ [[:xdigit:]]{2} )* ) | \g<attr> = \* | \g<attr> = \g<value>? \* (?: \g<value> \* )* \g<value>? | (?: \g<attr> (?: :dn )? (?: : (?<rule> [[:digit:]]+ (?: \. [[:digit:]]+ )* | [[:alpha:]] [[:alnum:]]* Match ) )? := \g<value> | (?: : (?: dn | DN ) )? : \g<rule> := \g<value> ) ) ) \) )? (?: \? \g<dn> \? \g<scope> \? \g<filter>? )* )? $/]
```

### <a name="sssdsubdomaininherit"></a>`SSSD::Subdomain::Inherit`

The SSSD::Subdomain::Inherit data type.

* **Since** 2.0.0

Alias of

```puppet
Enum['ignore_group_members', 'ldap_purge_cache_timeout', 'ldap_use_tokengroups', 'ldap_user_principal', 'ldap_krb5_keytab']
```

### <a name="sssdtype"></a>`SSSD::Type`

The SSSD::Type data type.

* **Since** 2.0.0

Alias of

```puppet
Enum['nss', 'pam', 'sudo', 'autofs', 'ssh', 'pac', 'ifp', 'secrets']
```

